Modules
- context_
plugin_ client - Generated client implementations.
- context_
plugin_ server - Generated server implementations.
- custom_
resource_ plugin_ client - Generated client implementations.
- custom_
resource_ plugin_ server - Generated server implementations.
- dns_
provider_ plugin_ client - Generated client implementations.
- dns_
provider_ plugin_ server - Generated server implementations.
- ingress_
plugin_ client - Generated client implementations.
- ingress_
plugin_ server - Generated server implementations.
- runtime_
plugin_ client - Generated client implementations.
- runtime_
plugin_ server - Generated server implementations.
- source_
plugin_ client - Generated client implementations.
- source_
plugin_ server - Generated server implementations.
Structs
- AddDomain
Request - AddDomain
Response - AppContext
- Convert
CrRequest - Convert
CrResponse - Download
AppRequest - Download
AppResponse - Download
Apps Request - Download
Apps Response - Empty
- GetApp
Store Metadata Request - GetApp
Store Metadata Response - GetContext
Request - GetIssuer
Config Request - Ingress
- Ingress
Option - Install
AppRequest - Install
AppResponse - IsSupported
AppRequest - IsSupported
AppResponse - Issuer
Config - Multi
Language Item - Parse
AppRequest - Parse
AppResponse - Pause
AppRequest - Pause
AppResponse - Provider
Setting - Provider
Settings - Provider
Settings Response - Register
AppRequest - Register
AppResponse - Remove
Domain Request - Remove
Domain Response - Resume
AppRequest - Resume
AppResponse - Setting
Option - Support
Check Request - Support
Check Response - Uninstall
AppRequest - Uninstall
AppResponse - Unregister
AppRequest - Unregister
AppResponse - User
State - Verify
Ownership Request - Verify
Ownership Response
Enums
- AppScope
- Ingress
Type - This is what the app declares as ingress type, a plugin ingress implementation may handle it differently
- Setting
Type