Module custom_resource_plugin_server

Module custom_resource_plugin_server 

Generated server implementations.

Structs

CustomResourcePluginServer
A CustomResource plugin declares a custom extension to the internal format

Constants

SERVICE_NAME
Generated gRPC service name

Traits

CustomResourcePlugin
Generated trait containing gRPC methods that should be implemented for use with CustomResourcePluginServer.