Module dns_provider_plugin_server

Module dns_provider_plugin_server 

Generated server implementations.

Structs

DnsProviderPluginServer
A parser/runtime plugin adds a custom parser for app files It may also contain a custom runtime for the app and just proxy to it

Constants

SERVICE_NAME
Generated gRPC service name

Traits

DnsProviderPlugin
Generated trait containing gRPC methods that should be implemented for use with DnsProviderPluginServer.