#[repr(i32)]pub enum IngressType {
HttpFallback = 0,
Https = 1,
TlsTcp = 2,
}Expand description
This is what the app declares as ingress type, a plugin ingress implementation may handle it differently
Variants
Implementations
Sourceimpl IngressType
impl IngressType
Sourceimpl IngressType
impl IngressType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<IngressType>
pub fn from_str_name(value: &str) -> Option<IngressType>
Creates an enum from field names used in the ProtoBuf definition.