Module runtime_plugin_client
n5i_
plugin_
common
0.8.0
Module runtime_
plugin_
client
Module Items
Structs
In n5i_
plugin_
common::
api
n5i_plugin_common
::
api
Module
runtime_
plugin_
client
Generated client implementations.
Structs

Runtime
Plugin
Client
A parser/runtime plugin adds a custom parser for app files It may also contain a custom runtime for the app and just proxy to it