Module source_plugin_server

Module source_plugin_server 

Generated server implementations.

Structs

SourcePluginServer
A source plugin adds support for a custom repository format In most cases, it is used together with a ParserPlugin. Apps will still be stored in the main app manager, a source plugin just provides a way to import them from a custom source, for example a custom HTTP-based protocol

Constants

SERVICE_NAME
Generated gRPC service name

Traits

SourcePlugin
Generated trait containing gRPC methods that should be implemented for use with SourcePluginServer.