pub struct DownloadAppResponse {
pub app_directory: Vec<u8>,
pub state: String,
}Fields
app_directory: Vec<u8>The directory of the app as a compressed tar archive (compressed using gzip)
state: StringJSON encoded state of the app repository to save (This is entirely up to the plugin)