pub struct Ingress {
pub target_service: Option<String>,
pub target_ns: Option<String>,
pub target_app: Option<String>,
pub path_prefix: Option<String>,
pub target_port: Option<u32>,
pub type: i32,
pub enable_compression: bool,
pub strip_prefix: bool,
pub auth_exclude: bool,
pub use_https: bool,
pub tls_insecure: bool,
}Fields
target_service: Option<String>target_ns: Option<String>target_app: Option<String>path_prefix: Option<String>target_port: Option<u32>type: i32enable_compression: boolstrip_prefix: boolauth_exclude: booluse_https: booltls_insecure: boolImplementations
Sourceimpl Ingress
impl Ingress
Sourcepub fn target_service(&self) -> &str
pub fn target_service(&self) -> &str
Returns the value of target_service, or the default value if target_service is unset.
Sourcepub fn target_ns(&self) -> &str
pub fn target_ns(&self) -> &str
Returns the value of target_ns, or the default value if target_ns is unset.
Sourcepub fn target_app(&self) -> &str
pub fn target_app(&self) -> &str
Returns the value of target_app, or the default value if target_app is unset.
Sourcepub fn path_prefix(&self) -> &str
pub fn path_prefix(&self) -> &str
Returns the value of path_prefix, or the default value if path_prefix is unset.
Sourcepub fn target_port(&self) -> u32
pub fn target_port(&self) -> u32
Returns the value of target_port, or the default value if target_port is unset.
Sourcepub fn type(&self) -> IngressType
pub fn type(&self) -> IngressType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: IngressType)
pub fn set_type(&mut self, value: IngressType)
Sets type to the provided enum value.