pub struct IngressOption {
pub id: String,
pub name: HashMap<String, String>,
pub can_choose_domain: bool,
pub domain_placeholder: HashMap<String, String>,
}Fields
id: StringUnique identifier for the ingress option, used later when adding domains
name: HashMap<String, String>The name, in a map language -> name
can_choose_domain: booldomain_placeholder: HashMap<String, String>If can_choose_domain is true, this is the placeholder for the domain input, in a map language -> placeholder