pub struct ProviderSetting {
pub name: Option<MultiLanguageItem>,
pub description: Option<MultiLanguageItem>,
pub required: bool,
pub default_value: Option<String>,
pub type: i32,
pub options: Vec<SettingOption>,
}Fields
name: Option<MultiLanguageItem>Human-readable name of the setting
description: Option<MultiLanguageItem>Description of the setting
required: boolWhether the setting is required
default_value: Option<String>Default value for the setting
type: i32Type of the setting (e.g., “string”, “boolean”, “number”)
options: Vec<SettingOption>If the setting has predefined options
Implementations
Sourceimpl ProviderSetting
impl ProviderSetting
Sourcepub fn default_value(&self) -> &str
pub fn default_value(&self) -> &str
Returns the value of default_value, or the default value if default_value is unset.
Sourcepub fn type(&self) -> SettingType
pub fn type(&self) -> SettingType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: SettingType)
pub fn set_type(&mut self, value: SettingType)
Sets type to the provided enum value.