pub struct Setting {
pub name: Option<MultiLanguageItem>,
pub description: Option<MultiLanguageItem>,
pub required: bool,
pub type: i32,
pub immutable: bool,
pub options: Option<Options>,
}Fields
name: Option<MultiLanguageItem>Human-readable name of the setting
description: Option<MultiLanguageItem>Description of the setting
required: boolWhether the setting is required
type: i32immutable: boolWhether the setting is immutable (can only be set at object creation time)
options: Option<Options>Implementations
Sourceimpl Setting
impl Setting
Sourcepub fn type(&self) -> SettingType
pub fn type(&self) -> SettingType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: SettingType)
pub fn set_type(&mut self, value: SettingType)
Sets type to the provided enum value.