Generated server implementations.
Structs
- Custom
Resource Plugin Server - A CustomResource plugin declares a custom extension to the internal format
Constants
- SERVICE_
NAME - Generated gRPC service name
Traits
- Custom
Resource Plugin - Generated trait containing gRPC methods that should be implemented for use with CustomResourcePluginServer.