Generated server implementations.
Structs
- DnsProvider
Plugin Server - A parser/runtime plugin adds a custom parser for app files It may also contain a custom runtime for the app and just proxy to it
Constants
- SERVICE_
NAME - Generated gRPC service name
Traits
- DnsProvider
Plugin - Generated trait containing gRPC methods that should be implemented for use with DnsProviderPluginServer.