Module runtime_plugin_client

Module runtime_plugin_client 

Generated client implementations.

Structs

RuntimePluginClient
A parser/runtime plugin adds a custom parser for app files It may also contain a custom runtime for the app and just proxy to it