Generated client implementations.
Structs
- Source
Plugin Client - A source plugin adds support for a custom repository format In most cases, it is used together with a ParserPlugin. Apps will still be stored in the main app manager, a source plugin just provides a way to import them from a custom source, for example a custom HTTP-based protocol