Module source_plugin_client

Module source_plugin_client 

Generated client implementations.

Structs

SourcePluginClient
A source plugin adds support for a custom repository format In most cases, it is used together with a ParserPlugin. Apps should still be stored within the main app manager, not within the plugin. This is to allow a source in one format to contain apps in another.