Generated server implementations.
Structs
- Source
Plugin Server - A source plugin adds support for a custom repository format In most cases, it is used together with a ParserPlugin. Apps will still be stored in the main app manager, a source plugin just provides a way to import them from a custom source, for example a custom HTTP-based protocol
Constants
- SERVICE_
NAME - Generated gRPC service name
Traits
- Source
Plugin - Generated trait containing gRPC methods that should be implemented for use with SourcePluginServer.