Generated server implementations.
Structs
- Source
Plugin Server - A source plugin adds support for a custom repository format In most cases, it is used together with a ParserPlugin. Apps should still be stored within the main app manager, not within the plugin. This is to allow a source in one format to contain apps in another.
Constants
- SERVICE_
NAME - Generated gRPC service name
Traits
- Source
Plugin - Generated trait containing gRPC methods that should be implemented for use with SourcePluginServer.