Module source_plugin_server

Module source_plugin_server 

Generated server implementations.

Structs

SourcePluginServer
A source plugin adds support for a custom repository format In most cases, it is used together with a ParserPlugin. Apps should still be stored within the main app manager, not within the plugin. This is to allow a source in one format to contain apps in another.

Constants

SERVICE_NAME
Generated gRPC service name

Traits

SourcePlugin
Generated trait containing gRPC methods that should be implemented for use with SourcePluginServer.